@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.0"
+version = "1.1.2"
 
 lean_metas = [
     {
@@ -454,6 +454,12 @@ def create_symlink_directory(directory, print_info=False):
                 print(f"Create symlink {link_name}")
             os.symlink(source, link_name)
 
+def set_exec_permission(directory):
+    for file in os.listdir(directory):
+        full_path = os.path.join(directory, file)
+        if os.path.isfile(full_path) and os.path.splitext(full_path)[1] == "":
+            print(f"Set execute permission: {full_path}")
+            os.chmod(full_path, stat.S_IRWXU)
 
 def __load_symbols(pyc_meta, load_lean_library=True):
 
@@ -544,10 +550,15 @@ def __load_symbols(pyc_meta, load_lean_library=True):
         print(f"Extract nvbinary to... {nv_root}")
         downloader.extract_zip_to(lean_zip_file, nv_root)
         open(nvbinary_md5_file, "w").write(remote_md5)
-        os.chmod(trtexec_path, stat.S_IRWXU)
-        os.chmod(nvcc_path, stat.S_IRWXU)
+
+        for d, ds, fs in os.walk(nv_root):
+            for itemd in ds:
+                if itemd == "bin":
+                    set_exec_permission(os.path.join(d, itemd))
+
         create_symlink_directory(nvlib64_root, True)
 
+
     if os.path.exists(pyc_version_path):
         current_pyc_version = open(pyc_version_path, "r").read()
         if current_pyc_version != version:
